@@ -17,12 +17,13 @@ from . import Magics
 class Context(object):
     def __init__(self):
         self.tmp = []
+        Magics.set_python()
         self.silent = True
 
     def set(self):
         if self.silent:
-            Magics.setc("magics_silent", "on")
             os.environ["MAGPLUS_WARNING"] = "off"
+            Magics.mute()
         else:
             os.environ["MAGPLUS_INFO"] = "on"
 
@@ -36,6 +37,18 @@ def silent():
     context.silent = False
 
 
+def unmute():
+    context.silent = False
+
+
+def mute():
+    context.silent = True
+
+
+def keep_compatibility():
+    Magics.keep_compatibility()
+
+
 @Magics.log
 def warning(int, msg):
     print(msg.decode())
@@ -380,6 +393,31 @@ class Action(object):
         else:
             print(f, "")
 
+    def to_yaml(self):
+        def tidy(x):
+            if isinstance(x, (list, tuple)):
+                return [tidy(y) for y in x]
+
+            if isinstance(x, dict):
+                d = {}
+                for k, v in x.items():
+                    d[k] = tidy(v)
+                return d
+
+            # Numpy arrays
+            if hasattr(x, "tolist"):
+                return x.tolist()
+
+            if x in ("on", "true", "yes"):
+                return True
+
+            if x in ("off", "false", "no"):
+                return False
+
+            return x
+
+        return {self.verb: tidy(self.args)}
+
     def clean_object(self, obj):
         if sys.version_info[0] < 3:
             if type(obj) in (int, float, str, bool, numpy.float64, numpy.float32):
@@ -443,14 +481,14 @@ class Action(object):
                 type = self.find_type(self.args[key])
                 if type == "int":
                     if dim == 2:
-                        Magics.set2i(key, numpy.int64(data), size[0], size[1])
+                        Magics.set2i(key, data.astype(numpy.int64), size[0], size[1])
                     else:
-                        Magics.set1i(key, numpy.int64(data), size[0])
+                        Magics.set1i(key, data.astype(numpy.int64), size[0])
                 elif type == "float":
                     if dim == 2:
-                        Magics.set2r(key, numpy.float64(data), size[1], size[0])
+                        Magics.set2r(key, data.astype(numpy.float64), size[1], size[0])
                     else:
-                        Magics.set1r(key, numpy.float64(data))
+                        Magics.set1r(key, data.astype(numpy.float64))
                 else:
                     print("can not interpret type %s for %s ???->", (type, key))
             else:
@@ -753,6 +791,19 @@ def _execute(o):
 
 def _plot(*args):
 
+    if os.environ.get("MAGICS_DUMP_YAML"):
+        import yaml
+
+        actions = []
+        for n in args:
+            if isinstance(n, (list, tuple)):
+                for v in n:
+                    actions.append(v.to_yaml())
+            else:
+                actions.append(n.to_yaml())
+        print(yaml.dump(dict(plot=actions), default_flow_style=False))
+        return
+
     context.set()
     # try :
     Magics.init()
@@ -887,9 +938,15 @@ def wmsstyles(data):
         styles = json.loads(styles.decode())
         return styles
     except:
+        Magics.finalize()
         return {}
 
 
+def known_drivers():
+
+    return Magics.known_drivers()
+
+
 def version():
     version = Magics.version()
     return version.decode()
